
# SDK in Python for Intralinks

This SDK is for educational purpose only. The goal is to learn how to leverage the Intralinks API in a programming language like Python.

Prerequisite:
* You should have created your account on the [Intralinks Developer Portal](https://developers.intralinks.com/)
* You should have requested and API Key on the Intralinks Developer Portal
* You should have an account on the test environment of Intralinks
* You should have installed the SDK for Intralinks : `pip install intralinks`

As a first step, you need to tell python to load the SDK:


```python
import intralinks
```

Then you need to log in on Intralinks. This part is a bit tricky so we will skip it for now. How? 
We will leverage the Intralinks Developer Portal.

You can use the following [procedure](https://github.com/ilapi/intralinks-api/blob/master/tutorial/INTRALINKS_AUTHENTICATION.md) to get a session token:


```python
session_token = '214mkH4cKOeFGcZ2H3eUkFblfC9n'
```

Now, you can init `il`, a client for Intralinks:


```python
il = intralinks.new_client('https://test-api.intralinks.com', session_token)
```

The `il` client will help ou to interact with Intralinks. For example, to get the list of exchanges you have access to:


```python
exchange_list = il.get_exchanges()
```

Where `exchange_list` equals:


```python
[{'workspaceName': 'Exchange 1',
  'parentTemplateId': 194471,
  'host': 'Demo Host',
  'securityLevel': 1,
  'type': 'ARC',
  'statistics': {'newTasks': 0, 'newParticipantRequests': 0},
  'pvpEnabled': False,
  'version': 1,
  'htmlViewEnabled': False,
  'phase': 'OPEN',
  'name': 'Exchange 1',
  'id': 1192451},
 {'workspaceName': 'Exchange 2',
  'parentTemplateId': 194471,
  'host': 'Demo Host',
  'securityLevel': 1,
  'type': 'ARC',
  'statistics': {'newTasks': 0, 'newParticipantRequests': 0},
  'pvpEnabled': False,
  'version': 1,
  'htmlViewEnabled': False,
  'phase': 'OPEN',
  'name': 'Exchange 2',
  'id': 1192461},
 {'workspaceName': 'Exchange 3',
  'parentTemplateId': 194471,
  'host': 'Demo Host',
  'securityLevel': 1,
  'type': 'ARC',
  'statistics': {'newTasks': 0, 'newParticipantRequests': 0},
  'pvpEnabled': False,
  'version': 1,
  'htmlViewEnabled': False,
  'phase': 'OPEN',
  'name': 'Exchange 3',
  'id': 1192471},
 {'workspaceName': 'Exchange 4',
  'parentTemplateId': 194471,
  'host': 'Demo Host',
  'securityLevel': 1,
  'type': 'ARC',
  'statistics': {'newTasks': 0, 'newParticipantRequests': 0},
  'pvpEnabled': False,
  'version': 1,
  'htmlViewEnabled': False,
  'phase': 'OPEN',
  'name': 'Exchange 4',
  'id': 1192481}]
```

Let's explore the first available exchange:


```python
exchange = exchange_list[0]
```

We need to check if there is a splash screen:


```python
splash = il.get_splash(exchange)
```

Where `splash` equals:


```python
{'acceptText': 'agree',
 'displayType': 'DISPLAY_EVERYTIME',
 'hasImage': True,
 'splashRequired': True,
 'splashText': 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.',
 'splashType': 'PUBLIC',
 'splashUrl': '',
 'workspaceName': 'Exchange 1'}
```

As the splash is required, we first need to accept it:


```python
if il.enter_exchange(exchange, accept_splash=True) == 'ALLOW':
    print('Allowed to enter the exchange')
else:
    print('Not allowed to enter the exchange')
```

    Allowed to enter the exchange
    

Now we can get the list of documents:


```python
document_list = il.get_documents(exchange)
```

Where `document_list` equals:


```python
[{'id': 58114077,
  'name': 'Document 1.1',
  'orderNumber': 1,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130357,
  'createdOn': {'milliseconds': 1544794073000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794074000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 1',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977427,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'},
 {'id': 58093647,
  'name': 'Document 1.2',
  'orderNumber': 2,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130357,
  'createdOn': {'milliseconds': 1544794075000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794075000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 1',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977537,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'},
 {'id': 58114087,
  'name': 'Document 2.1',
  'orderNumber': 1,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130367,
  'createdOn': {'milliseconds': 1544794078000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794079000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 2',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977487,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'},
 {'id': 58093657,
  'name': 'Document 2.2',
  'orderNumber': 2,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130367,
  'createdOn': {'milliseconds': 1544794080000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794080000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 2',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977547,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'},
 {'id': 58114097,
  'name': 'Document 3.1',
  'orderNumber': 1,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130377,
  'createdOn': {'milliseconds': 1544794082000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794082000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 3',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977497,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'},
 {'id': 58093667,
  'name': 'Document 3.2',
  'orderNumber': 2,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130377,
  'createdOn': {'milliseconds': 1544794083000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794085000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 3',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977507,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'},
 {'id': 58114107,
  'name': 'Document 4.1',
  'orderNumber': 1,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130387,
  'createdOn': {'milliseconds': 1544794089000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794089000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 4',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977517,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'},
 {'id': 58093677,
  'name': 'Document 4.2',
  'orderNumber': 2,
  'version': 'da4b9237bacccdf19c0760cab7aec4a8359010b0',
  'fileSize': 0,
  'fileHashDownload': 'SKVEjMS/fXZkOcE7LT7j6b7zVNQ=',
  'mimeType': 'NONE/NONE',
  'noteRequired': False,
  'parentId': 58130387,
  'createdOn': {'milliseconds': 1544794090000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'submittedOn': {},
  'submittedBy': {},
  'submitterGroups': {},
  'lastModifiedOn': {'milliseconds': 1544794090000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'unread': True,
  'pageCount': 0,
  'workspaceId': 1192451,
  'versionNumber': 0,
  'isFavorite': False,
  'parentName': 'Folder 4',
  'pdfProtection': 'NONE',
  'hasNote': False,
  'isIrmSecured': False,
  'isDeleted': False,
  'isBusinessProcessEnabled': False,
  'documentHash': '0',
  'xmlLock': {'contentLockStatus': 'UNLOCKED'},
  'sharedResourceId': 11977527,
  'sharedResourceCount': 0,
  'entityType': 'DOCUMENT'}]
```

We can get the list of folders:


```python
folder_list = il.get_folders(exchange)
```

Where `folder_list` equals:


```python
[{'id': 58130357,
  'name': 'Folder 1',
  'indexNumber': '',
  'orderNumber': 1,
  'version': '356a192b7913b04c54574d18c28d46e6395428ab',
  'hasChildFolders': False,
  'indexingDisabled': False,
  'createdOn': {'milliseconds': 1544794070000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'lastModifiedOn': {'milliseconds': 1544794070000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'isFavorite': False,
  'versionNumber': 0,
  'isEmailin': False},
 {'id': 58130367,
  'name': 'Folder 2',
  'indexNumber': '',
  'orderNumber': 2,
  'version': '356a192b7913b04c54574d18c28d46e6395428ab',
  'hasChildFolders': False,
  'indexingDisabled': False,
  'createdOn': {'milliseconds': 1544794077000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'lastModifiedOn': {'milliseconds': 1544794077000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'isFavorite': False,
  'versionNumber': 0,
  'isEmailin': False},
 {'id': 58130377,
  'name': 'Folder 3',
  'indexNumber': '',
  'orderNumber': 3,
  'version': '356a192b7913b04c54574d18c28d46e6395428ab',
  'hasChildFolders': False,
  'indexingDisabled': False,
  'createdOn': {'milliseconds': 1544794082000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'lastModifiedOn': {'milliseconds': 1544794082000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'isFavorite': False,
  'versionNumber': 0,
  'isEmailin': False},
 {'id': 58130387,
  'name': 'Folder 4',
  'indexNumber': '',
  'orderNumber': 4,
  'version': '356a192b7913b04c54574d18c28d46e6395428ab',
  'hasChildFolders': False,
  'indexingDisabled': False,
  'createdOn': {'milliseconds': 1544794087000},
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith',
   'organization': 'Big Corp',
   'organizationSort': 'Big Corp'},
  'lastModifiedOn': {'milliseconds': 1544794087000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'isFavorite': False,
  'versionNumber': 0,
  'isEmailin': False}]
```

The list of exchange members:


```python
exchange_member_list = il.get_exchange_members(exchange)
```

Where `exchange_member_list` equals:


```python
[{'version': 'fe8f7a66754bd9b6b31d24d480d90567b920704c',
  'userId': 443391,
  'firstName': 'John',
  'firstNameSort': 'John',
  'lastName': 'Smith',
  'lastNameSort': 'Smith',
  'organization': 'Big Corp',
  'organizationSort': 'Big Corp',
  'roleType': 'MANAGER',
  'keyContact': False,
  'isPlaceholderUser': False,
  'officePhone': '+1 212 543 7800',
  'country': 'FRANCE',
  'status': 'ACTIVE',
  'createdBy': {'firstName': 'John',
   'lastName': 'Doe',
   'firstNameSort': 'John',
   'lastNameSort': 'Doe'},
  'createdOn': {'milliseconds': 1544797508000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Doe',
   'firstNameSort': 'John',
   'lastNameSort': 'Doe'},
  'lastModifiedOn': {'milliseconds': 1544797508000},
  'firstAccessed': {'milliseconds': 1544792140000},
  'lastAccessedOn': {'milliseconds': 1544796731000},
  'industry': 'AEROSPACE',
  'title': 'ASSISTANT_SUPPORT_STAFF',
  'doNotSendAlert': False,
  'functionalArea': 'CONSULTING_ADVISORY',
  'alertPreference': 'IMMEDIATE',
  'cgFlag': 'M',
  'isWelcomeAlertSent': True,
  'lastAlertSentDate': {'milliseconds': 1544797509000},
  'eitherASubmitterOrCoordinator': False,
  'id': 349075541,
  'emailId': 'omangez@intralinks.com'},
 {'version': '088648d65d3ebf87f870a63fb1b0b341a15d5417',
  'userId': 1907341,
  'firstName': 'John',
  'firstNameSort': 'John',
  'lastName': 'Doe',
  'lastNameSort': 'Doe',
  'organization': 'Big Corp',
  'organizationSort': 'Big Corp',
  'roleType': 'MANAGER_PLUS',
  'keyContact': True,
  'isPlaceholderUser': False,
  'officePhone': '0000',
  'country': 'UNITED_STATES',
  'status': 'ACTIVE',
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'createdOn': {'milliseconds': 1544794066000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'lastModifiedOn': {'milliseconds': 1544797394000},
  'firstAccessed': {'milliseconds': 1544797300000},
  'lastAccessedOn': {'milliseconds': 1544946664000},
  'industry': 'UNAVAILABLE',
  'title': 'UNAVAILABLE',
  'doNotSendAlert': False,
  'functionalArea': 'UNAVAILABLE',
  'alertPreference': 'IMMEDIATE',
  'cgFlag': 'M',
  'viewPrivatePreference': 'Y',
  'isWelcomeAlertSent': True,
  'eitherASubmitterOrCoordinator': False,
  'id': 349075421,
  'emailId': 'john.doe@bigcorp.com'},
 {'version': 'ca5b703a3180dff3a999c5bb255a22dfcd51d90f',
  'userId': 1907351,
  'firstName': 'Bill',
  'firstNameSort': 'Bill',
  'lastName': 'Trump',
  'lastNameSort': 'Trump',
  'organization': 'Red Org',
  'organizationSort': 'Red Org',
  'roleType': 'REVIEWER',
  'keyContact': False,
  'isPlaceholderUser': False,
  'officePhone': '0000',
  'status': 'ACTIVE',
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'createdOn': {'milliseconds': 1544794067000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'lastModifiedOn': {'milliseconds': 1544794067000},
  'doNotSendAlert': False,
  'alertPreference': 'IMMEDIATE',
  'isWelcomeAlertSent': True,
  'eitherASubmitterOrCoordinator': False,
  'id': 349075431,
  'emailId': 'bill.trump@red.com'},
 {'version': '87975206bcae207bbb6a58e6b558b78e3d2ae0c4',
  'userId': 1907361,
  'firstName': 'Donald',
  'firstNameSort': 'Donald',
  'lastName': 'Clinton',
  'lastNameSort': 'Clinton',
  'organization': 'Yellow Org',
  'organizationSort': 'Yellow Org',
  'roleType': 'REVIEWER',
  'keyContact': False,
  'isPlaceholderUser': False,
  'officePhone': '0000',
  'status': 'ACTIVE',
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'createdOn': {'milliseconds': 1544794070000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'lastModifiedOn': {'milliseconds': 1544794070000},
  'doNotSendAlert': False,
  'alertPreference': 'IMMEDIATE',
  'isWelcomeAlertSent': True,
  'eitherASubmitterOrCoordinator': False,
  'id': 349075441,
  'emailId': 'donald.clinton@yellow.com'}]
```

The list of groups and the associated exchange members:


```python
group_list, group_member_list = il.get_groups_and_members(exchange)
```

Where `group_list` equals:


```python
[{'version': '0b2c1b2e978c07ff2dabcebb1f76e390d527789f',
  'groupName': 'Group 4',
  'groupType': 'WORKSPACE',
  'ftsEnabled': False,
  'note': ' ',
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'createdOn': {'milliseconds': 1544794091000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'lastModifiedOn': {'milliseconds': 1544794198000},
  'groupMemberCount': 1,
  'buyerGroupDetails': {},
  'id': 6474391},
 {'version': '6e34372a1d71a4281374a36b8bd4633ae9a04b18',
  'groupName': 'Group 1',
  'groupType': 'WORKSPACE',
  'ftsEnabled': False,
  'note': ' ',
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'createdOn': {'milliseconds': 1544794076000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'lastModifiedOn': {'milliseconds': 1544794076000},
  'groupMemberCount': 0,
  'buyerGroupDetails': {},
  'id': 6474361},
 {'version': '32e492965595115eeb708098582f2a3d1692b885',
  'groupName': 'Group 2',
  'groupType': 'WORKSPACE',
  'ftsEnabled': False,
  'note': ' ',
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'createdOn': {'milliseconds': 1544794081000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'lastModifiedOn': {'milliseconds': 1544794191000},
  'groupMemberCount': 1,
  'buyerGroupDetails': {},
  'id': 6474371},
 {'version': '6e068359e80984f0bbe6a3474e3d2b047fe9552c',
  'groupName': 'Group 3',
  'groupType': 'WORKSPACE',
  'ftsEnabled': False,
  'note': ' ',
  'createdBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'createdOn': {'milliseconds': 1544794086000},
  'lastModifiedBy': {'firstName': 'John',
   'lastName': 'Smith',
   'firstNameSort': 'John',
   'lastNameSort': 'Smith'},
  'lastModifiedOn': {'milliseconds': 1544794086000},
  'groupMemberCount': 0,
  'buyerGroupDetails': {},
  'id': 6474381}]
```

Where `group_member_list` equals:


```python
[{'workspaceGroupId': 6474391,
  'workspaceUserId': 349075431,
  'userId': 1907351},
 {'workspaceGroupId': 6474371,
  'workspaceUserId': 349075441,
  'userId': 1907361}]
```


```python

```
